@@ -130,7 +130,7 @@
 #include <iostream>
 #include <string>
 
-#include "textstyleformatterfactory.h"
+#include "formatterfactory.h"
 #include "colors.h"
 #include "keys.h"
 #include "parsestyles.h"
@@ -141,6 +141,8 @@
 
 using std::cerr;
 
+using namespace srchilite;
+
 extern int line;
 
 static int yyparse() ;
@@ -149,7 +151,7 @@ static void yyerror( const char *s ) ;
 // line is defined in styleparser
 
 // to generate the formatter for each language element
-static TextStyleFormatterFactory *formatterFactory;
+static FormatterFactory *formatterFactory;
 
 static void updateBgColor(const std::string &c);
 
@@ -192,16 +194,16 @@ static string errorBuffer;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 68 "./stylecssparser.yy"
+#line 70 "./stylecssparser.yy"
 {
   int tok ; /* command */
   const std::string * string ; /* string : id, ... */
-  StyleConstant flag ;
-  StyleConstants *styleconstants;
-  KeyList *keylist;
+  srchilite::StyleConstant flag ;
+  srchilite::StyleConstants *styleconstants;
+  srchilite::KeyList *keylist;
 }
 /* Line 187 of yacc.c.  */
-#line 205 "stylecssparser.cc"
+#line 207 "stylecssparser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -214,7 +216,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 218 "stylecssparser.cc"
+#line 220 "stylecssparser.cc"
 
 #ifdef short
 # undef short
@@ -503,9 +505,9 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    88,    88,    89,    92,    93,    96,   100,    99,   141,
-     147,   155,   156,   159,   160,   161,   164,   169,   176,   181,
-     188,   189,   190,   191,   192,   193
+       0,    90,    90,    91,    94,    95,    98,   102,   101,   143,
+     149,   157,   158,   161,   162,   163,   166,   171,   178,   183,
+     190,   191,   192,   193,   194,   195
 };
 #endif
 
@@ -1114,44 +1116,44 @@ yydestruct (yymsg, yytype, yyvaluep)
   switch (yytype)
     {
       case 9: /* "KEY" */
-#line 81 "./stylecssparser.yy"
+#line 83 "./stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1123 "stylecssparser.cc"
+#line 1125 "stylecssparser.cc"
 	break;
       case 10: /* "COLOR" */
-#line 81 "./stylecssparser.yy"
+#line 83 "./stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1131 "stylecssparser.cc"
+#line 1133 "stylecssparser.cc"
 	break;
       case 11: /* "BG_COLOR" */
-#line 81 "./stylecssparser.yy"
+#line 83 "./stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1139 "stylecssparser.cc"
+#line 1141 "stylecssparser.cc"
 	break;
       case 12: /* "STRINGDEF" */
-#line 81 "./stylecssparser.yy"
+#line 83 "./stylecssparser.yy"
 	{
 	if ((yyvaluep->string))
 	  delete (yyvaluep->string);
 };
-#line 1147 "stylecssparser.cc"
+#line 1149 "stylecssparser.cc"
 	break;
       case 22: /* "keylist" */
-#line 81 "./stylecssparser.yy"
+#line 83 "./stylecssparser.yy"
 	{
 	if ((yyvaluep->keylist))
 	  delete (yyvaluep->keylist);
 };
-#line 1155 "stylecssparser.cc"
+#line 1157 "stylecssparser.cc"
 	break;
 
       default:
@@ -1460,12 +1462,12 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 88 "./stylecssparser.yy"
+#line 90 "./stylecssparser.yy"
     { /* allow empty files */ }
     break;
 
   case 7:
-#line 100 "./stylecssparser.yy"
+#line 102 "./stylecssparser.yy"
     {
                //printSequence( $1 ) ;
                //printMessage_noln( ": " ) ;
@@ -1476,7 +1478,7 @@ yyreduce:
     break;
 
   case 8:
-#line 108 "./stylecssparser.yy"
+#line 110 "./stylecssparser.yy"
     {
                KeyType key;
                KeyList *keylist = (yyvsp[(1) - (4)].keylist);
@@ -1511,7 +1513,7 @@ yyreduce:
     break;
 
   case 9:
-#line 142 "./stylecssparser.yy"
+#line 144 "./stylecssparser.yy"
     {
               (yyvsp[(1) - (3)].keylist)->push_back(*(yyvsp[(3) - (3)].string));
               (yyval.keylist) = (yyvsp[(1) - (3)].keylist);
@@ -1520,7 +1522,7 @@ yyreduce:
     break;
 
   case 10:
-#line 148 "./stylecssparser.yy"
+#line 150 "./stylecssparser.yy"
     {
               (yyval.keylist) = new KeyList;
               (yyval.keylist)->push_back(*(yyvsp[(1) - (1)].string));
@@ -1529,12 +1531,12 @@ yyreduce:
     break;
 
   case 11:
-#line 155 "./stylecssparser.yy"
+#line 157 "./stylecssparser.yy"
     {}
     break;
 
   case 16:
-#line 165 "./stylecssparser.yy"
+#line 167 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1542,7 +1544,7 @@ yyreduce:
     break;
 
   case 17:
-#line 170 "./stylecssparser.yy"
+#line 172 "./stylecssparser.yy"
     {
           currentColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1550,7 +1552,7 @@ yyreduce:
     break;
 
   case 18:
-#line 177 "./stylecssparser.yy"
+#line 179 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1558,7 +1560,7 @@ yyreduce:
     break;
 
   case 19:
-#line 182 "./stylecssparser.yy"
+#line 184 "./stylecssparser.yy"
     {
           currentBGColor = *(yyvsp[(1) - (1)].string);
           delete (yyvsp[(1) - (1)].string);
@@ -1566,38 +1568,38 @@ yyreduce:
     break;
 
   case 20:
-#line 188 "./stylecssparser.yy"
+#line 190 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISBOLD); }
     break;
 
   case 21:
-#line 189 "./stylecssparser.yy"
+#line 191 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISITALIC); }
     break;
 
   case 22:
-#line 190 "./stylecssparser.yy"
+#line 192 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISUNDERLINE); }
     break;
 
   case 23:
-#line 191 "./stylecssparser.yy"
+#line 193 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISFIXED); }
     break;
 
   case 24:
-#line 192 "./stylecssparser.yy"
+#line 194 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOTFIXED); }
     break;
 
   case 25:
-#line 193 "./stylecssparser.yy"
+#line 195 "./stylecssparser.yy"
     { currentStyleConstants->push_back(ISNOREF); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 1601 "stylecssparser.cc"
+#line 1603 "stylecssparser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1811,14 +1813,30 @@ yyreturn:
 }
 
 
-#line 196 "./stylecssparser.yy"
+#line 198 "./stylecssparser.yy"
 
 
 // string current_file; defined in styleparser
 
 extern string current_file;
 
-void parseCssStyles(const string &path, const string &name, TextStyleFormatterFactory *genFactory,
+void
+yyerror( const char *s )
+{
+  errorBuffer = s;
+}
+
+void updateBgColor(const std::string &c)
+{
+  if (bodyBgColor != "")
+    yyerror("bgcolor already defined");
+  else
+    bodyBgColor = c;
+}
+
+namespace srchilite {
+
+void parseCssStyles(const string &path, const string &name, FormatterFactory *genFactory,
                    string &bodyBgColor_)
 {
   formatterFactory = genFactory;
@@ -1850,17 +1868,5 @@ void parseCssStyles(const string &path, const string &name, TextStyleFormatterFa
   }
 }
 
-void
-yyerror( const char *s )
-{
-  errorBuffer = s;
-}
-
-void updateBgColor(const std::string &c)
-{
-  if (bodyBgColor != "")
-    yyerror("bgcolor already defined");
-  else
-    bodyBgColor = c;
 }
 
